@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2026 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -142,7 +142,7 @@ SCIP_RETCODE assignVars(
             /* check if bins are in same cluster */
             if( SCIPisEQ(scip, 1.0, clustering[i][c] * clustering[j][c]) )
             {
-               var = edgevars[i][j][0];
+               var = edgevars[i][j][INCLUSTER];
                if( var != NULL && SCIPisGE(scip, SCIPvarGetUbGlobal(var), clustering[j][c] * clustering[i][c])
                   && SCIPvarGetStatus(var) != SCIP_VARSTATUS_MULTAGGR )
                {
@@ -153,7 +153,7 @@ SCIP_RETCODE assignVars(
             /* check if bins are in consecutive clusters */
             else if( SCIPisEQ(scip, 1.0, clustering[i][c] * clustering[j][phi(c, ncluster)]) )
             {
-               var = edgevars[i][j][1];
+               var = edgevars[i][j][CONSECUTIVE_CLUSTER];
                if( var != NULL && SCIPvarGetStatus(var) != SCIP_VARSTATUS_MULTAGGR &&
                   SCIPisGE(scip, SCIPvarGetUbGlobal(var), clustering[j][phi(c, ncluster)] * clustering[i][c]) )
                {
@@ -163,7 +163,7 @@ SCIP_RETCODE assignVars(
 
             else if( SCIPisEQ(scip, 1.0, clustering[j][c] * clustering[i][phi(c, ncluster)]) )
             {
-               var = edgevars[j][i][1];
+               var = edgevars[j][i][CONSECUTIVE_CLUSTER];
                if( var != NULL && SCIPvarGetStatus(var) != SCIP_VARSTATUS_MULTAGGR &&
                   SCIPisGE(scip, SCIPvarGetUbGlobal(var), clustering[j][c] * clustering[i][phi(c, ncluster)]) )
                {
@@ -214,7 +214,7 @@ SCIP_RETCODE createVariables(
    int i;
    int j;
    int c;
-   int edgetype;
+   EDGETYPE edgetype;
    int nbins = probdata->nbins;
    int ncluster = probdata->ncluster;
    char varname[SCIP_MAXSTRLEN];
@@ -238,9 +238,7 @@ SCIP_RETCODE createVariables(
       }
    }
 
-   /* create variables for the edges in each cluster combination. Index 0 are edges within cluster, 1 edges between
-    * consequtive clusters and 2 edges between non-consequtive clusters
-    */
+   /* create variables for the edges in each cluster combination.*/
    SCIP_CALL( SCIPallocBlockMemoryArray(scip, &(probdata->edgevars), nbins) );
 
    for( i = 0; i < nbins; ++i )
@@ -257,9 +255,9 @@ SCIP_RETCODE createVariables(
 
          SCIP_CALL( SCIPallocClearBlockMemoryArray(scip, &(probdata->edgevars[i][j]), 3) ); /*lint !e866*/
 
-         for( edgetype = 0; edgetype < 3; ++edgetype )
+         for( edgetype = INCLUSTER; edgetype <= NON_CONSECUTIVE_CLUSTER; ++edgetype )
          {
-            if( edgetype == 0 && i < j )
+            if( edgetype == INCLUSTER && i < j )
                continue;
 
             (void)SCIPsnprintf(varname, SCIP_MAXSTRLEN, "y_%d_%d_%d", i, j, edgetype);
@@ -284,6 +282,7 @@ SCIP_RETCODE createProbSimplifiedTest(
    int j;
    int c1;
    int c2;
+   EDGETYPE edgetype;
    char consname[SCIP_MAXSTRLEN];
    SCIP_CONS* temp;
    int nbins = probdata->nbins;
@@ -320,12 +319,12 @@ SCIP_RETCODE createProbSimplifiedTest(
             continue;
 
          /* these edges are not within a cluster */
-         SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][0],
+         SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][INCLUSTER],
             (probdata->cmatrix[i][j] + probdata->cmatrix[j][i]) * scale) );
 
          /* these are the edges that are between consequtive clusters */
-         SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][1], (probdata->cmatrix[i][j] - probdata->cmatrix[j][i])) );
-         SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[j][i][1], (probdata->cmatrix[j][i] - probdata->cmatrix[i][j])) );
+         SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][CONSECUTIVE_CLUSTER], (probdata->cmatrix[i][j] - probdata->cmatrix[j][i])) );
+         SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[j][i][CONSECUTIVE_CLUSTER], (probdata->cmatrix[j][i] - probdata->cmatrix[i][j])) );
 
          /* create constraints that determine when the edge-variables have to be non-zero */
          for( c1 = 0; c1 < ncluster; ++c1 )
@@ -335,7 +334,7 @@ SCIP_RETCODE createProbSimplifiedTest(
             SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE ) );
 
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][0], -1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][INCLUSTER], -1.0) );
             SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][c1], 1.0) );
             SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[j][c1], 1.0) );
 
@@ -351,11 +350,11 @@ SCIP_RETCODE createProbSimplifiedTest(
                   continue;
 
                if( c2 == c1 + 1 || ( c2 == 0 && c1 == ncluster -1) )
-                  var = probdata->edgevars[i][j][1];
+                  var = probdata->edgevars[i][j][CONSECUTIVE_CLUSTER];
                else if( c2 == c1 - 1 || ( c1 == 0 && c2 == ncluster -1) )
-                  var = probdata->edgevars[j][i][1];
+                  var = probdata->edgevars[j][i][CONSECUTIVE_CLUSTER];
                else
-                  var = probdata->edgevars[i][j][2];
+                  var = probdata->edgevars[i][j][NON_CONSECUTIVE_CLUSTER];
 
                /* if two bins are in a different cluster -> the corresponding edge must be cut */
                (void)SCIPsnprintf(consname, SCIP_MAXSTRLEN, "bins_%d_%d_inclusters_%d_%d", i+1, j+1, c1+1, c2+1 );
@@ -384,11 +383,11 @@ SCIP_RETCODE createProbSimplifiedTest(
          (void)SCIPsnprintf(consname, SCIP_MAXSTRLEN, "sumedge_%d_%d",  i+1, j+1 );
          SCIP_CALL( SCIPcreateConsBasicLinear(scip, &temp, consname, 0, NULL, NULL, 1.0, 1.0 ) );
 
-         for( c1 = 0; c1 < 3; ++c1 )
+         for( edgetype = INCLUSTER; edgetype <= NON_CONSECUTIVE_CLUSTER; ++edgetype )
          {
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][c1], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][edgetype], 1.0) );
          }
-         SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][1], 1.0) );
+         SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][CONSECUTIVE_CLUSTER], 1.0) );
 
          SCIP_CALL( SCIPaddCons(scip, temp) );
          SCIP_CALL( SCIPreleaseCons(scip, &temp) );
@@ -425,6 +424,7 @@ SCIP_RETCODE createProbSimplified(
    int i;
    int j;
    int c1;
+   EDGETYPE edgetype;
    int nbins = probdata->nbins;
    int ncluster = probdata->ncluster;
    char consname[SCIP_MAXSTRLEN];
@@ -469,13 +469,13 @@ SCIP_RETCODE createProbSimplified(
          if( ncluster > 3 )
          {
             /* these edges are within a cluster */
-            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][0],
+            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][INCLUSTER],
                (probdata->cmatrix[i][j] + probdata->cmatrix[j][i]) * scale) );
 
             /* these are the edges that are between consequtive clusters */
-            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][1],
+            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][CONSECUTIVE_CLUSTER],
                (probdata->cmatrix[i][j] - probdata->cmatrix[j][i])) );
-            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[j][i][1],
+            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[j][i][CONSECUTIVE_CLUSTER],
                (probdata->cmatrix[j][i] - probdata->cmatrix[i][j])) );
 
             /* create constraints that determine when the edge-variables have to be non-zero*/
@@ -486,10 +486,10 @@ SCIP_RETCODE createProbSimplified(
                SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                   TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE) );
 
-               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][0], -1.0) );
+               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][INCLUSTER], -1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][c1], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[j][c1], 1.0) );
-               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][1], 1.0) );
+               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][CONSECUTIVE_CLUSTER], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][phiinv(c1, ncluster)], -1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[j][phi(c1, ncluster)], -1.0) );
 
@@ -500,10 +500,10 @@ SCIP_RETCODE createProbSimplified(
                SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                   TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE) );
 
-               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][0], -1.0) );
+               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][INCLUSTER], -1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][c1], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[j][c1], 1.0) );
-               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][1], 1.0) );
+               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][CONSECUTIVE_CLUSTER], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][phi(c1, ncluster)], -1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[j][phiinv(c1, ncluster)], -1.0) );
 
@@ -514,10 +514,10 @@ SCIP_RETCODE createProbSimplified(
                SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                   TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE) );
 
-               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][1], -1.0) );
+               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][CONSECUTIVE_CLUSTER], -1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][c1], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[j][phi(c1, ncluster)], 1.0) );
-               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][0], 1.0) );
+               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][INCLUSTER], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][phi(c1, ncluster)], -1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[j][c1], -1.0) );
 
@@ -528,10 +528,10 @@ SCIP_RETCODE createProbSimplified(
                SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                   TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE) );
 
-               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][1], -1.0) );
+               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][CONSECUTIVE_CLUSTER], -1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][c1], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[j][phiinv(c1,ncluster)], 1.0) );
-               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][0], 1.0) );
+               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][INCLUSTER], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][phiinv(c1, ncluster)], -1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[j][c1], -1.0) );
 
@@ -543,10 +543,10 @@ SCIP_RETCODE createProbSimplified(
          else
          {
             /* these are the edges that are between consequtive clusters */
-            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][1],
+            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][CONSECUTIVE_CLUSTER],
                (probdata->cmatrix[i][j] - probdata->cmatrix[j][i])
                - (probdata->cmatrix[i][j] + probdata->cmatrix[j][i]) * scale) );
-            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[j][i][1],
+            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[j][i][CONSECUTIVE_CLUSTER],
                (probdata->cmatrix[j][i] - probdata->cmatrix[i][j])
                   - (probdata->cmatrix[i][j] + probdata->cmatrix[j][i]) * scale) );
 
@@ -558,9 +558,9 @@ SCIP_RETCODE createProbSimplified(
                (void)SCIPsnprintf(consname, SCIP_MAXSTRLEN, "bins_%d_%d_incluster_%d", i, j, c1);
                SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                   TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE) );
-               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][1], -1.0) );
+               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][CONSECUTIVE_CLUSTER], -1.0) );
 
-               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][1], 1.0) );
+               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][CONSECUTIVE_CLUSTER], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][c1], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[j][phi(c1, ncluster)], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][phiinv(c1, ncluster)], -1.0) );
@@ -573,8 +573,8 @@ SCIP_RETCODE createProbSimplified(
                SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                   TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE) );
 
-               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][1], -1.0) );
-               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][1], 1.0) );
+               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][CONSECUTIVE_CLUSTER], -1.0) );
+               SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][CONSECUTIVE_CLUSTER], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[j][c1], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][phi(c1, ncluster)], 1.0) );
                SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->binvars[i][phiinv(c1, ncluster)], -1.0) );
@@ -599,12 +599,12 @@ SCIP_RETCODE createProbSimplified(
          (void)SCIPsnprintf(consname, SCIP_MAXSTRLEN, "sumedge_%d_%d",  i, j);
          SCIP_CALL( SCIPcreateConsBasicLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0) );
 
-         for( c1 = 0; c1 < 2; ++c1 )
+         for( edgetype = INCLUSTER; edgetype <= CONSECUTIVE_CLUSTER; ++edgetype )
          {
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][c1], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][edgetype], 1.0) );
          }
 
-         SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][1], 1.0) );
+         SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][CONSECUTIVE_CLUSTER], 1.0) );
 
          SCIP_CALL( SCIPaddCons(scip, temp) );
          SCIP_CALL( SCIPreleaseCons(scip, &temp) );
@@ -860,18 +860,18 @@ SCIP_RETCODE createProbOnlyEdge(
          /* these edges are not within a cluster */
          if( j < i )
          {
-            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][0], (probdata->cmatrix[i][j] + probdata->cmatrix[j][i]) * scale) );
+            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][INCLUSTER], (probdata->cmatrix[i][j] + probdata->cmatrix[j][i]) * scale) );
             /* these are the edges that are between consequtive clusters */
-            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][1], (probdata->cmatrix[i][j] - probdata->cmatrix[j][i])) );
-            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[j][i][1], (probdata->cmatrix[j][i] - probdata->cmatrix[i][j])) );
+            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[i][j][CONSECUTIVE_CLUSTER], (probdata->cmatrix[i][j] - probdata->cmatrix[j][i])) );
+            SCIP_CALL( SCIPchgVarObj(scip, probdata->edgevars[j][i][CONSECUTIVE_CLUSTER], (probdata->cmatrix[j][i] - probdata->cmatrix[i][j])) );
 
             (void)SCIPsnprintf(consname, SCIP_MAXSTRLEN, "bins_%d_%d", i+1, j+1);
             SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE) );
 
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][0], 1.0) );
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][1], 1.0) );
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][1], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][INCLUSTER], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][CONSECUTIVE_CLUSTER], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][i][CONSECUTIVE_CLUSTER], 1.0) );
 
             SCIP_CALL( SCIPaddCons(scip, temp) );
             SCIP_CALL( SCIPreleaseCons(scip, &temp) );
@@ -890,9 +890,9 @@ SCIP_RETCODE createProbOnlyEdge(
                   SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                      TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE) );
 
-                  SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][0], sign[l][0]) );
-                  SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][k][0], sign[l][1]) );
-                  SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][k][0], sign[l][2]) );
+                  SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][j][INCLUSTER], sign[l][0]) );
+                  SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][k][INCLUSTER], sign[l][1]) );
+                  SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][k][INCLUSTER], sign[l][2]) );
 
                   SCIP_CALL( SCIPaddCons(scip, temp) );
                   SCIP_CALL( SCIPreleaseCons(scip, &temp) );
@@ -903,9 +903,9 @@ SCIP_RETCODE createProbOnlyEdge(
             SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE) );
 
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[MAX(i,j)][MIN(i,j)][0], 1.0) );
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][k][1], 1.0) );
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][k][1], -1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[MAX(i,j)][MIN(i,j)][INCLUSTER], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][k][CONSECUTIVE_CLUSTER], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][k][CONSECUTIVE_CLUSTER], -1.0) );
 
             SCIP_CALL( SCIPaddCons(scip, temp) );
             SCIP_CALL( SCIPreleaseCons(scip, &temp) );
@@ -914,9 +914,9 @@ SCIP_RETCODE createProbOnlyEdge(
             SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE) );
 
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[MAX(i,j)][MIN(i,j)][0], 1.0) );
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[k][j][1], 1.0) );
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[k][i][1], -1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[MAX(i,j)][MIN(i,j)][INCLUSTER], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[k][j][CONSECUTIVE_CLUSTER], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[k][i][CONSECUTIVE_CLUSTER], -1.0) );
 
             SCIP_CALL( SCIPaddCons(scip, temp) );
             SCIP_CALL( SCIPreleaseCons(scip, &temp) );
@@ -925,9 +925,9 @@ SCIP_RETCODE createProbOnlyEdge(
             SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE) );
 
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[MAX(i,j)][MIN(i,j)][0], -1.0) );
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][k][1], 1.0) );
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][k][1], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[MAX(i,j)][MIN(i,j)][INCLUSTER], -1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[j][k][CONSECUTIVE_CLUSTER], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[i][k][CONSECUTIVE_CLUSTER], 1.0) );
 
             SCIP_CALL( SCIPaddCons(scip, temp) );
             SCIP_CALL( SCIPreleaseCons(scip, &temp) );
@@ -936,9 +936,9 @@ SCIP_RETCODE createProbOnlyEdge(
             SCIP_CALL( SCIPcreateConsLinear(scip, &temp, consname, 0, NULL, NULL, -SCIPinfinity(scip), 1.0,
                TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE) );
 
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[MAX(i,j)][MIN(i,j)][0], -1.0) );
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[k][j][1], 1.0) );
-            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[k][i][1], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[MAX(i,j)][MIN(i,j)][INCLUSTER], -1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[k][j][CONSECUTIVE_CLUSTER], 1.0) );
+            SCIP_CALL( SCIPaddCoefLinear(scip, temp, probdata->edgevars[k][i][CONSECUTIVE_CLUSTER], 1.0) );
 
             SCIP_CALL( SCIPaddCons(scip, temp) );
             SCIP_CALL( SCIPreleaseCons(scip, &temp) );
@@ -956,7 +956,7 @@ SCIP_DECL_PROBTRANS(probtransCyc)
    int i;
    int j;
    int c;
-   int edgetype;
+   EDGETYPE edgetype;
    int nbins = sourcedata->nbins;
    int ncluster = sourcedata->ncluster;
 
@@ -999,9 +999,9 @@ SCIP_DECL_PROBTRANS(probtransCyc)
          if( sourcedata->edgevars[i][j] == NULL || i == j)
             continue;
          SCIP_CALL( SCIPallocClearBlockMemoryArray(scip, &((*targetdata)->edgevars[i][j]), 3) ); /*lint !e866*/
-         for( edgetype = 0; edgetype < 3; ++edgetype )
+         for( edgetype = INCLUSTER; edgetype <= NON_CONSECUTIVE_CLUSTER; ++edgetype )
          {
-            if( edgetype == 0 && i < j )
+            if( edgetype == INCLUSTER && i < j )
                continue;
             if( sourcedata->edgevars[i][j][edgetype] != NULL )
             {
@@ -1039,7 +1039,7 @@ static
 SCIP_DECL_PROBDELORIG(probdelorigCyc)
 {
    int c;
-   int edgetype;
+   EDGETYPE edgetype;
    int i;
    int j;
 
@@ -1068,9 +1068,9 @@ SCIP_DECL_PROBDELORIG(probdelorigCyc)
       {
          if( (*probdata)->edgevars[i][j] != NULL && j != i )
          {
-            for ( edgetype = 0; edgetype < 3; ++edgetype )
+            for( edgetype = INCLUSTER; edgetype <= NON_CONSECUTIVE_CLUSTER; ++edgetype )
             {
-               if( edgetype == 0 && i < j )
+               if( edgetype == INCLUSTER && i < j )
                   continue;
 
                if( (*probdata)->edgevars[i][j][edgetype] != NULL )
@@ -1108,7 +1108,7 @@ static
 SCIP_DECL_PROBDELTRANS(probdeltransCyc)
 {
    int c;
-   int edgetype;
+   EDGETYPE edgetype;
    int i;
    int j;
 
@@ -1137,9 +1137,9 @@ SCIP_DECL_PROBDELTRANS(probdeltransCyc)
       {
          if( (*probdata)->edgevars[i][j] != NULL && j != i )
          {
-            for ( edgetype = 0; edgetype < 3; ++edgetype )
+            for( edgetype = INCLUSTER; edgetype <= NON_CONSECUTIVE_CLUSTER; ++edgetype )
             {
-               if( 0 == edgetype && j > i )
+               if( edgetype == INCLUSTER && j > i )
                   continue;
 
                if( (*probdata)->edgevars[i][j][edgetype] != NULL )
@@ -1180,7 +1180,7 @@ SCIP_DECL_PROBCOPY(probcopyCyc)
    SCIP_VAR* var;
    int nbins;
    int ncluster;
-   int edgetype;
+   EDGETYPE edgetype;
    int i;
    int j;
    int c;
@@ -1232,7 +1232,7 @@ SCIP_DECL_PROBCOPY(probcopyCyc)
 
          SCIP_CALL( SCIPallocBlockMemoryArray(scip, &((*targetdata)->edgevars[i][j]), 3) );  /*lint !e866*/
 
-         for( edgetype = 0; edgetype < 3; ++edgetype )
+         for( edgetype = INCLUSTER; edgetype <= NON_CONSECUTIVE_CLUSTER; ++edgetype )
          {
             if( edgetype == 0 && j > i )
                continue;
@@ -1481,15 +1481,15 @@ SCIP_VAR* getEdgevar(
    SCIP_VAR****          edgevars,           /**< edgevar data structure*/
    int                   state1,             /**< first state */
    int                   state2,             /**< second state */
-   int                   direction           /**< direction, 0 = incluster, 1 = forward */
+   EDGETYPE              edgetype            /**< position in clustering */
    )
 {
    assert(edgevars != NULL);
    assert(edgevars[state1] != NULL);
    assert(edgevars[state1][state2] != NULL);
-   assert(edgevars[state1][state2][direction] != NULL);
+   assert(edgevars[state1][state2][edgetype] != NULL);
 
-   return edgevars[state1][state2][direction];
+   return edgevars[state1][state2][edgetype];
 }
 
 /** check for an array of states, if all possible edge-combinations exist */
