@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2026 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -40,7 +40,7 @@ namespace tsp
 {
 
 /** C++ rounding heuristic for TSP */
-class HeurFrats : public scip::ObjHeur
+class HeurFrats : public scip::ObjHeur /*lint --e{3713}*/
 {
    GRAPH*                graph;              /**< the underlying graph of the TSP */
    SCIP_SOL*             sol;                /**< current solution */
