@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2026 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -44,7 +44,7 @@ namespace tsp
 {
 
 /** SCIP file reader for TSP data files */
-class ReaderTSP : public scip::ObjReader
+class ReaderTSP : public scip::ObjReader /*lint --e{3713}*/
 {
 public:
 
