@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2026 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -194,7 +194,39 @@ SCIP_RETCODE SCIPcreateObjVar(
    vardata->deleteobject = deleteobject;
 
    /* create variable */
-   SCIP_CALL( SCIPcreateVar(scip, var, name, lb, ub, obj, vartype, initial, removable, 
+   SCIP_CALL( SCIPcreateVar(scip, var, name, lb, ub, obj, vartype, initial, removable,
+         varDelorigObj, varTransObj, varDeltransObj, varCopyObj, vardata) ); /*lint !e429*/
+
+   return SCIP_OKAY; /*lint !e429*/
+}
+
+/** create and capture problem variable with implied type and associates the given variable data with the variable;
+ *  if variable is of integral type, fractional bounds are automatically rounded
+ */
+SCIP_RETCODE SCIPcreateObjVarImpl(
+   SCIP*                 scip,               /**< SCIP data structure */
+   SCIP_VAR**            var,                /**< pointer to variable object */
+   const char*           name,               /**< name of variable, or NULL for automatic name creation */
+   SCIP_Real             lb,                 /**< lower bound of variable */
+   SCIP_Real             ub,                 /**< upper bound of variable */
+   SCIP_Real             obj,                /**< objective function value */
+   SCIP_VARTYPE          vartype,            /**< type of variable */
+   SCIP_IMPLINTTYPE      impltype,           /**< implied integral type of the variable */
+   SCIP_Bool             initial,            /**< should var's column be present in the initial root LP? */
+   SCIP_Bool             removable,          /**< is var's column removable from the LP (due to aging or cleanup)? */
+   scip::ObjVardata*     objvardata,         /**< user variable data object */
+   SCIP_Bool             deleteobject        /**< should the user variable data object be deleted when variable is freed? */
+   )
+{
+   SCIP_VARDATA* vardata;
+
+   /* create user variable data */
+   vardata = new SCIP_VARDATA;
+   vardata->objvardata = objvardata;
+   vardata->deleteobject = deleteobject;
+
+   /* create variable */
+   SCIP_CALL( SCIPcreateVarImpl(scip, var, name, lb, ub, obj, vartype, impltype, initial, removable,
          varDelorigObj, varTransObj, varDeltransObj, varCopyObj, vardata) ); /*lint !e429*/
 
    return SCIP_OKAY; /*lint !e429*/
