@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2026 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -1268,6 +1268,8 @@ static SCIP_DECL_HEUREXEC(heurExecPADM)
       SCIP_VAR* var;
       const char* vname;
 
+      assert(linkvartoblocks[i].indexes != NULL);
+
       vname = SCIPvarGetName(linkvars[i]);
       k = 0;
       for( b = 0; b < problem->nblocks; b++ )
@@ -1445,7 +1447,7 @@ static SCIP_DECL_HEUREXEC(heurExecPADM)
                   SCIP_Real initval;
 
                   initval = SCIPvarGetLPSol(linkvars[linkvaridx]);
-                  if( SCIPvarGetType(binfo->linkvar) != SCIP_VARTYPE_CONTINUOUS )
+                  if( SCIPvarIsIntegral(binfo->linkvar) )
                      initval = SCIPround(scip, initval);
 
                   SCIP_CALL( SCIPcreateConsBasicLinear((problem->blocks[b]).subscip, &((problem->blocks[b]).couplingcons[j]),
@@ -2047,16 +2049,15 @@ SCIP_RETCODE SCIPincludeHeurPADM(
    SCIP_CALL( SCIPallocBlockMemory(scip, &heurdata) );
 
    /* include primal heuristic */
-
-   /* use SCIPincludeHeurBasic() plus setter functions if you want to set callbacks one-by-one and your code should
-    * compile independent of new callbacks being added in future SCIP versions
-    */
    SCIP_CALL( SCIPincludeHeurBasic(scip, &heur,
                HEUR_NAME, HEUR_DESC, HEUR_DISPCHAR, HEUR_PRIORITY, HEUR_FREQ, HEUR_FREQOFS,
                HEUR_MAXDEPTH, HEUR_TIMING, HEUR_USESSUBSCIP, heurExecPADM, heurdata) );
 
    assert(heur != NULL);
 
+   /* primal heuristic is safe to use in exact solving mode */
+   SCIPheurMarkExact(heur);
+
    /* set non fundamental callbacks via setter functions */
    SCIP_CALL( SCIPsetHeurCopy(scip, heur, heurCopyPADM) );
    SCIP_CALL( SCIPsetHeurFree(scip, heur, heurFreePADM) );
